%global pkgname thermal_daemon

Summary:	Thermal Management daemon
Name:		thermald
Version:	2.5.2
Release:	7%{?dist}
License:	GPLv2+
URL:		https://github.com/intel/%{pkgname}
Source0:	%{url}/archive/v%{version}/%{name}-%{version}.tar.gz #/%{pkgname}-%{version}.tar.gz
Source1:        %{name}-monitor.desktop
Source2:        %{name}-monitor.svg
Patch3000:      qcustomplot.patch

ExclusiveArch:	x86_64

BuildRequires:  gcc-c++ make automake autoconf autoconf-archive
BuildRequires:	dbus-glib-devel desktop-file-utils systemd-devel
BuildRequires:	libxml2-devel upower-devel libevdev-devel
BuildRequires:  gtk-doc
Requires:	dbus

Requires(pre):	glibc-common
Requires(pre):	shadow-utils

%{?systemd_requires}


%description
%{name} monitors and controls platform temperature.

Thermal issues are important to reduce performance impact. %{name} uses
the existing Linux kernel infrastructure and can be easily enhanced.


%package monitor
Summary:	Application for monitoring %{name}
License:	GPLv3+

BuildRequires:	qt5-qtbase-devel
Requires:	hicolor-icon-theme
Requires:	%{name}	== %{version}-%{release}
Provides:	bundled(qcustomplot) = 2.0.0-beta

%description monitor
This package contains an Application to monitor %{name} for system developers
and customers with the responsive and flexible thermal management.


%prep
%autosetup -n %{pkgname}-%{version} -p 1


%build
NO_CONFIGURE=1 ./autogen.sh
%configure --disable-option-checking --disable-silent-rules
%make_build

pushd tools/thermal_monitor
sed -i -e 's/-lqcustomplot/-lqcustomplot-qt5/' ThermalMonitor.pro
mkdir -p %{_target_platform}
pushd %{_target_platform}
%{qmake_qt5} ..
%make_build
popd
popd


%install
%make_install

install -Dpm 0755 tools/thermald_set_pref.sh %{buildroot}%{_bindir}/%{name}-set-pref

mkdir -p %{buildroot}%{_datadir}
mv -f %{buildroot}%{_sysconfdir}/dbus-1/* %{buildroot}%{_datadir}/dbus-1/

rm -rf %{buildroot}%{_sysconfdir}/init

cat << EOF > %{name}.conf
d %{_rundir}/%{name} 0755 root root -
EOF
install -Dpm 0644 %{name}.conf %{buildroot}%{_tmpfilesdir}/%{name}.conf

install -dm 0755 %{buildroot}%{_rundir}/%{name}
echo "%{name}_pid" > %{buildroot}%{_rundir}/%{name}/%{name}.pid
chmod -c 0644 %{buildroot}%{_rundir}/%{name}/%{name}.pid

install -Dpm 0755 tools/thermal_monitor/%{_target_platform}/ThermalMonitor %{buildroot}%{_bindir}/ThermalMonitor
install -Dpm 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}-monitor.desktop
install -Dpm 0644 %{SOURCE2} %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}-monitor.svg


%check
%{_bindir}/desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop


%pre
/bin/getent group power >/dev/null || /sbin/groupadd -r power
exit 0

%post
%systemd_post thermald.service

%preun
%systemd_preun thermald.service

%postun
%systemd_postun_with_restart thermald.service


%files
%license COPYING
%doc README.txt thermal_daemon_usage.txt
%config(noreplace) %{_sysconfdir}/%{name}
%ghost %dir %{_rundir}/%{name}
%ghost %{_rundir}/%{name}/%{name}.pid
%{_bindir}/%{name}-set-pref
%{_sbindir}/%{name}
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service
%{_datadir}/dbus-1/system-services/org.freedesktop.%{name}.service
%{_datadir}/dbus-1/system.d/org.freedesktop.%{name}.conf
%{_mandir}/man5/thermal-conf.xml.5*
%{_mandir}/man8/%{name}.8*


%files monitor
%license tools/thermal_monitor/COPYING
%{_bindir}/ThermalMonitor
%{_datadir}/applications/%{name}-monitor.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}-monitor.svg


%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.2-7
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.2-6
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.2-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 18 2023 cunshunxia <cunshunxia@tencent.com> - 2.5.2-4
- Rebuilt for upower 1.90.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.2-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.2-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 29 2023 rockerzhu <rockerzhu@tencent.com> - 2.5.2-1
- Initial build
